
import json

import redis
from flask import current_app

'''
http://www.cnblogs.com/melonjiang/p/5342505.html
自定义缓存redis
author:aniulee
time:2018-10-17
'''


class RedisCache(object):
    def __init__(self, host=None, port=None, db=None, password=None, prefix=None):

        if not hasattr(RedisCache, 'pool'):
            RedisCache.create_pool(host, port, db, password)
        self.prefix = prefix
        self._connection = redis.Redis(connection_pool=RedisCache.pool)

    @staticmethod
    def create_pool(host, port, db, password):
        if host is None:
            host = current_app.config.get('MY_REDIS_HOST')
        if password is None:
            password = current_app.config.get('MY_REDIS_PASSWORD', None)

        port = port or 6379
        db = db or 0
        if password:
            RedisCache.pool = redis.ConnectionPool(host=host, port=port, db=db, password=password)
        else:
            RedisCache.pool = redis.ConnectionPool(host=host, port=port, db=db)

    '''
    redis 对象 可以用来拓展
    '''

    def getInstance(self):
        return self._connection

    '''
    添加
    timeout 秒
    '''

    def set(self, key, value, timeout=None):
        prefix = self.prefix or ''
        value = json.dumps({
            'value': value
        })
        return self._connection.set("%s%s" % (prefix, key), value, ex=timeout)

    '''
    与set一模一样
    '''

    def add(self, key, value, timeout=None):
        return self.set(key, value, timeout)

    '''
    获取
    '''

    def get(self, key):
        prefix = self.prefix or ''
        ret_data = self._connection.get("%s%s" % (prefix, key))
        if ret_data is not None:
            if isinstance(ret_data, bytes):
                ret = ret_data.decode('utf-8')
                ret = json.loads(ret)
                return ret['value']
        return ret_data

    '''
    单个删除
    '''

    def delete(self, key):
        return self._connection.delete(key)

    '''
    清除所有
    '''

    def clear(self, prefix=None):
        if prefix is None:
            prefix = self.prefix or '*'
        keys = self._connection.keys(pattern='%s*' % prefix)
        if keys:
            for kk in keys:
                kk = kk.decode('utf-8')
                self.getInstance().delete(kk)
        return True


if __name__ == '__main__':
    pass
    # red = RedisCache(host='127.0.0.1',db=0,prefix='flask_blg')

    # red.set('cc',2,timeout=120)
    # red.set('aa',3,timeout=120)
    # red.set('bb',4,timeout=60)
    # red.clear()
    # print(red.delete('aniulee'))
    # print(red.get('aniulee'))
    # print(red.get('cc'))
    # red.set('test','1',timeout=10)
    # ret = red.get('test')
    # print(ret)
    # print(type(ret))



# coding:utf -8
import smtplib
from email.mime.text import MIMEText

from notetool import SecretManage
from notetool.tool.log import log

logger = log("ba-crawler")


def send_mail_163(subject="有货了", content="抢到了，快找牛哥，晚了就没了", receive="1007530194@qq.com"):
    if receive is None:
        receive = ["1007530194@qq.com"]
    elif isinstance(receive, str):
        receive = [receive]

    sender = "15068733021@163.com"  # 发送方
    secret = SecretManage()
    password = secret.read("mail", "163", "password")
    message = MIMEText(content, "plain", "utf-8")
    # content 发送内容     "plain"文本格式   utf-8 编码格式

    message['Subject'] = subject  # 邮件标题
    message['To'] = receive[0]  # 收件人
    message['From'] = sender  # 发件人

    smtp = smtplib.SMTP_SSL("smtp.163.com", 994)  # 实例化smtp服务器
    smtp.login(sender, password)  # 发件人登录
    # as_string 对 message 的消息进行了封装
    smtp.sendmail(sender, receive, message.as_string())
    smtp.close()
    logger.info("sen to {} success".format(receive))



#!/usr/bin/python3
# -*- coding:utf-8 -*-
from functools import wraps

import redis
import requests
from flask import current_app, jsonify
from notejob.center.configs import configs

'''
推送
https://www.aniulee.com
'''


def wechat_info_err(titile, content=''):
    try:
        api_key = configs('error_notice_api_key')
        if api_key:
            post_url = 'https://api.aniulee.com/blog_api_go/api/v1/push'
            data = {
                'api_key': api_key,
                'content': content,
                'title': titile
            }
            resp = requests.post(post_url, data=data, timeout=2, headers={'user-agent': 'XNCron'})
            print(resp.json())
    except Exception as e:
        current_app.logger.error("推送有BUG【%s】" % str(e))


def web_api_return(code, msg='ok', url=''):
    return jsonify({
        'errcode': code,
        'errmsg': msg,
        'url': url
    })


def dict2string(dict_data, separator="&&"):
    dd = separator.join("%s=%s" % (v, dict_data[v]) for v in dict_data)
    return dd


# 单节点任务装饰器，被装饰的任务在分布式多节点下同一时间只能运行一次
def single_task():
    def wrap(func):
        @wraps(func)
        def inner(*args, **kwargs):
            task = func.__name__

            config = configs()

            is_single = config.get('is_single')

            if is_single and is_single != '1':

                if config.get('redis_pwd'):
                    pool = redis.ConnectionPool(host=config.get('redis_host'), port=config.get('redis_port') or 6379,
                                                db=config.get('redis_db') or 0, password=config.get('redis_pwd'))
                else:
                    pool = redis.ConnectionPool(host=config.get('redis_host'), port=config.get('redis_port') or 6379,
                                                db=config.get('redis_db') or 0)

                r = redis.Redis(connection_pool=pool)

                task_id = args[0] if args else ''

                task_name = "task:%s:%s" % (task, task_id)
                _result = r.get(task_name)

                if not _result:
                    r.set(task_name, 1, ex=2*60)
                    try:
                        result = func(*args, **kwargs)
                        return result
                    except Exception as e:
                        raise e
                    finally:
                        r.delete(task_name)
                else:
                    return
            else:
                result = func(*args, **kwargs)
                return result
        return inner
    return wrap




from flask import jsonify


def Success(errcode=0, errmsg='good!success!', data=None, url=None, status=200):
    return jsonify({
        'errcode': errcode,
        'errmsg': errmsg,
        'result': data,
        'url': url
    }), status


'''
error 
'''


def Fail(errcode=1, errmsg='error!', data=None, url=None, status=500):
    return jsonify({
        'errcode': errcode,
        'errmsg': errmsg,
        'result': data,
        'url': url
    }), status


def api_return(errcode=0, errmsg='error', data=None):
    if errmsg is None and errcode == 1:
        errmsg = 'error!!'
    if errmsg is None and errcode == 0:
        errmsg = 'success!'

    return jsonify({
        "errcode": errcode,
        "errmsg": errmsg,
        "data": data
    })



from os import path

from notebuild.tool import read_version
from setuptools import find_packages, setup

version_path = path.join(path.abspath(path.dirname(__file__)), 'script/__version__.md')


install_requires = ['apscheduler', 'gunicorn', 'flask-migrate', 'flask-script']

setup(name='notejob',
      version=read_version(version_path),
      description='notejob',
      author='niuliangtao',
      author_email='1007530194@qq.com',
      url='https://github.com/1007530194',
      #entry_points={'console_scripts': ['notejob = notejob.core:notejob']},
      packages=find_packages(),
      #package_data={"notejob": ["*", "*.html", "*.js", "*.*"]},
      package_data={"": ["*.js","*.*"]},
      #include_package_data=True,
      install_requires=install_requires
      )
